@@ -40,7 +40,7 @@ class AsyncSearchClient(NamespacedClient):
         Deletes an async search by ID. If the search is still running, the search request
         will be cancelled. Otherwise, the saved search results are deleted.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/async-search.html>`_
 
         :param id: The async search ID
         """
@@ -82,7 +82,7 @@ class AsyncSearchClient(NamespacedClient):
         Retrieves the results of a previously submitted async search request given its
         ID.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/async-search.html>`_
 
         :param id: The async search ID
         :param keep_alive: Specify the time interval in which the results (partial or
@@ -131,7 +131,7 @@ class AsyncSearchClient(NamespacedClient):
         Retrieves the status of a previously submitted async search request given its
         ID.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/async-search.html>`_
 
         :param id: The async search ID
         """
@@ -245,8 +245,8 @@ class AsyncSearchClient(NamespacedClient):
         scroll: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
         search_after: t.Optional[
             t.Union[
-                t.List[t.Union[None, float, int, str]],
-                t.Tuple[t.Union[None, float, int, str], ...],
+                t.List[t.Union[None, bool, float, int, str, t.Any]],
+                t.Tuple[t.Union[None, bool, float, int, str, t.Any], ...],
             ]
         ] = None,
         search_type: t.Optional[
@@ -295,7 +295,7 @@ class AsyncSearchClient(NamespacedClient):
         """
         Executes a search request asynchronously.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/async-search.html>`_
 
         :param index: A comma-separated list of index names to search; use `_all` or
             empty string to perform the operation on all indices
