@@ -39,7 +39,7 @@ class CcrClient(NamespacedClient):
         """
         Deletes auto-follow patterns.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/ccr-delete-auto-follow-pattern.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/ccr-delete-auto-follow-pattern.html>`_
 
         :param name: The name of the auto follow pattern.
         """
@@ -77,13 +77,17 @@ class CcrClient(NamespacedClient):
         max_outstanding_write_requests: t.Optional[int] = None,
         max_read_request_operation_count: t.Optional[int] = None,
         max_read_request_size: t.Optional[str] = None,
-        max_retry_delay: t.Optional[t.Union[int, str]] = None,
+        max_retry_delay: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
         max_write_buffer_count: t.Optional[int] = None,
         max_write_buffer_size: t.Optional[str] = None,
         max_write_request_operation_count: t.Optional[int] = None,
         max_write_request_size: t.Optional[str] = None,
         pretty: t.Optional[bool] = None,
-        read_poll_timeout: t.Optional[t.Union[int, str]] = None,
+        read_poll_timeout: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
         remote_cluster: t.Optional[str] = None,
         wait_for_active_shards: t.Optional[
             t.Union[int, t.Union["t.Literal['all', 'index-setting']", str]]
@@ -92,7 +96,7 @@ class CcrClient(NamespacedClient):
         """
         Creates a new follower index configured to follow the referenced leader index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/ccr-put-follow.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/ccr-put-follow.html>`_
 
         :param index: The name of the follower index
         :param leader_index:
@@ -176,7 +180,7 @@ class CcrClient(NamespacedClient):
         Retrieves information about all follower indices, including parameters and status
         for each follower index
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/ccr-get-follow-info.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/ccr-get-follow-info.html>`_
 
         :param index: A comma-separated list of index patterns; use `_all` to perform
             the operation on all indices
@@ -214,7 +218,7 @@ class CcrClient(NamespacedClient):
         Retrieves follower stats. return shard-level stats about the following tasks
         associated with each shard for the specified indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/ccr-get-follow-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/ccr-get-follow-stats.html>`_
 
         :param index: A comma-separated list of index patterns; use `_all` to perform
             the operation on all indices
@@ -257,7 +261,7 @@ class CcrClient(NamespacedClient):
         """
         Removes the follower retention leases from the leader.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/ccr-post-forget-follower.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/ccr-post-forget-follower.html>`_
 
         :param index: the name of the leader index for which specified follower retention
             leases should be removed
@@ -308,7 +312,7 @@ class CcrClient(NamespacedClient):
         Gets configured auto-follow patterns. Returns the specified auto-follow pattern
         collection.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/ccr-get-auto-follow-pattern.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/ccr-get-auto-follow-pattern.html>`_
 
         :param name: Specifies the auto-follow pattern collection that you want to retrieve.
             If you do not specify a name, the API returns information for all collections.
@@ -346,7 +350,7 @@ class CcrClient(NamespacedClient):
         """
         Pauses an auto-follow pattern
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/ccr-pause-auto-follow-pattern.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/ccr-pause-auto-follow-pattern.html>`_
 
         :param name: The name of the auto follow pattern that should pause discovering
             new indices to follow.
@@ -384,7 +388,7 @@ class CcrClient(NamespacedClient):
         Pauses a follower index. The follower index will not fetch any additional operations
         from the leader index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/ccr-post-pause-follow.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/ccr-post-pause-follow.html>`_
 
         :param index: The name of the follower index that should pause following its
             leader index.
@@ -430,13 +434,17 @@ class CcrClient(NamespacedClient):
         max_outstanding_write_requests: t.Optional[int] = None,
         max_read_request_operation_count: t.Optional[int] = None,
         max_read_request_size: t.Optional[t.Union[int, str]] = None,
-        max_retry_delay: t.Optional[t.Union[int, str]] = None,
+        max_retry_delay: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
         max_write_buffer_count: t.Optional[int] = None,
         max_write_buffer_size: t.Optional[t.Union[int, str]] = None,
         max_write_request_operation_count: t.Optional[int] = None,
         max_write_request_size: t.Optional[t.Union[int, str]] = None,
         pretty: t.Optional[bool] = None,
-        read_poll_timeout: t.Optional[t.Union[int, str]] = None,
+        read_poll_timeout: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
         settings: t.Optional[t.Mapping[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
@@ -444,7 +452,7 @@ class CcrClient(NamespacedClient):
         cluster. Newly created indices on the remote cluster matching any of the specified
         patterns will be automatically configured as follower indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/ccr-put-auto-follow-pattern.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/ccr-put-auto-follow-pattern.html>`_
 
         :param name: The name of the collection of auto-follow patterns.
         :param remote_cluster: The remote cluster containing the leader indices to match
@@ -558,7 +566,7 @@ class CcrClient(NamespacedClient):
         """
         Resumes an auto-follow pattern that has been paused
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/ccr-resume-auto-follow-pattern.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/ccr-resume-auto-follow-pattern.html>`_
 
         :param name: The name of the auto follow pattern to resume discovering new indices
             to follow.
@@ -596,18 +604,22 @@ class CcrClient(NamespacedClient):
         max_outstanding_write_requests: t.Optional[int] = None,
         max_read_request_operation_count: t.Optional[int] = None,
         max_read_request_size: t.Optional[str] = None,
-        max_retry_delay: t.Optional[t.Union[int, str]] = None,
+        max_retry_delay: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
         max_write_buffer_count: t.Optional[int] = None,
         max_write_buffer_size: t.Optional[str] = None,
         max_write_request_operation_count: t.Optional[int] = None,
         max_write_request_size: t.Optional[str] = None,
         pretty: t.Optional[bool] = None,
-        read_poll_timeout: t.Optional[t.Union[int, str]] = None,
+        read_poll_timeout: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Resumes a follower index that has been paused
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/ccr-post-resume-follow.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/ccr-post-resume-follow.html>`_
 
         :param index: The name of the follow index to resume following.
         :param max_outstanding_read_requests:
@@ -681,7 +693,7 @@ class CcrClient(NamespacedClient):
         """
         Gets all stats related to cross-cluster replication.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/ccr-get-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/ccr-get-stats.html>`_
         """
         __path = "/_ccr/stats"
         __query: t.Dict[str, t.Any] = {}
@@ -714,7 +726,7 @@ class CcrClient(NamespacedClient):
         Stops the following task associated with a follower index and removes index metadata
         and settings associated with cross-cluster replication.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/ccr-post-unfollow.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/ccr-post-unfollow.html>`_
 
         :param index: The name of the follower index that should be turned into a regular
             index.
