@@ -46,7 +46,7 @@ class ClusterClient(NamespacedClient):
         """
         Provides explanations for shard allocations in the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/cluster-allocation-explain.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/cluster-allocation-explain.html>`_
 
         :param current_node: Specifies the node ID or the name of the node to only explain
             a shard that is currently located on the specified node.
@@ -111,7 +111,7 @@ class ClusterClient(NamespacedClient):
         """
         Deletes a component template
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/indices-component-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/indices-component-template.html>`_
 
         :param name: Comma-separated list or wildcard expression of component template
             names used to limit the request.
@@ -154,7 +154,7 @@ class ClusterClient(NamespacedClient):
         """
         Clears cluster voting config exclusions.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/voting-config-exclusions.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/voting-config-exclusions.html>`_
 
         :param wait_for_removal: Specifies whether to wait for all excluded nodes to
             be removed from the cluster before clearing the voting configuration exclusions
@@ -199,7 +199,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns information about whether a particular component template exist
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/indices-component-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/indices-component-template.html>`_
 
         :param name: Comma-separated list of component template names used to limit the
             request. Wildcard (*) expressions are supported.
@@ -251,7 +251,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns one or more component templates
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/indices-component-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/indices-component-template.html>`_
 
         :param name: The comma separated names of the component templates
         :param flat_settings:
@@ -303,7 +303,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns cluster settings.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/cluster-get-settings.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/cluster-get-settings.html>`_
 
         :param flat_settings: Return settings in flat format (default: false)
         :param include_defaults: Whether to return all default clusters setting.
@@ -389,7 +389,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns basic information about the health of the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/cluster-health.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/cluster-health.html>`_
 
         :param index: Comma-separated list of data streams, indices, and index aliases
             used to limit the request. Wildcard expressions (*) are supported. To target
@@ -484,7 +484,7 @@ class ClusterClient(NamespacedClient):
         Returns a list of any cluster-level changes (e.g. create index, update mapping,
         allocate or fail shard) which have not yet been executed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/cluster-pending.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/cluster-pending.html>`_
 
         :param local: Return local information, do not retrieve the state from master
             node (default: false)
@@ -530,7 +530,7 @@ class ClusterClient(NamespacedClient):
         """
         Updates the cluster voting config exclusions by node ids or node names.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/voting-config-exclusions.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/voting-config-exclusions.html>`_
 
         :param node_ids: A comma-separated list of the persistent ids of the nodes to
             exclude from the voting configuration. If specified, you may not also specify
@@ -572,37 +572,40 @@ class ClusterClient(NamespacedClient):
         *,
         name: str,
         template: t.Mapping[str, t.Any],
-        aliases: t.Optional[t.Mapping[str, t.Mapping[str, t.Any]]] = None,
+        allow_auto_create: t.Optional[bool] = None,
         create: t.Optional[bool] = None,
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[
             t.Union[str, t.Union[t.List[str], t.Tuple[str, ...]]]
         ] = None,
         human: t.Optional[bool] = None,
-        mappings: t.Optional[t.Mapping[str, t.Any]] = None,
         master_timeout: t.Optional[
             t.Union["t.Literal[-1]", "t.Literal[0]", str]
         ] = None,
         meta: t.Optional[t.Mapping[str, t.Any]] = None,
         pretty: t.Optional[bool] = None,
-        settings: t.Optional[t.Mapping[str, t.Any]] = None,
         version: t.Optional[int] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Creates or updates a component template
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/indices-component-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/indices-component-template.html>`_
 
         :param name: The name of the template
-        :param template:
-        :param aliases:
+        :param template: The template to be applied which includes mappings, settings,
+            or aliases configuration.
+        :param allow_auto_create: This setting overrides the value of the `action.auto_create_index`
+            cluster setting. If set to `true` in a template, then indices can be automatically
+            created using that template even if auto-creation of indices is disabled
+            via `actions.auto_create_index`. If set to `false` then data streams matching
+            the template must always be explicitly created.
         :param create: Whether the index template should only be added if new or can
             also replace an existing one
-        :param mappings:
         :param master_timeout: Specify timeout for connection to master
-        :param meta:
-        :param settings:
-        :param version:
+        :param meta: Optional user metadata about the component template. May have any
+            contents. This map is not automatically generated by Elasticsearch.
+        :param version: Version number used to manage component templates externally.
+            This number isn't automatically generated or incremented by Elasticsearch.
         """
         if name in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'name'")
@@ -613,8 +616,8 @@ class ClusterClient(NamespacedClient):
         __query: t.Dict[str, t.Any] = {}
         if template is not None:
             __body["template"] = template
-        if aliases is not None:
-            __body["aliases"] = aliases
+        if allow_auto_create is not None:
+            __body["allow_auto_create"] = allow_auto_create
         if create is not None:
             __query["create"] = create
         if error_trace is not None:
@@ -623,16 +626,12 @@ class ClusterClient(NamespacedClient):
             __query["filter_path"] = filter_path
         if human is not None:
             __query["human"] = human
-        if mappings is not None:
-            __body["mappings"] = mappings
         if master_timeout is not None:
             __query["master_timeout"] = master_timeout
         if meta is not None:
             __body["_meta"] = meta
         if pretty is not None:
             __query["pretty"] = pretty
-        if settings is not None:
-            __body["settings"] = settings
         if version is not None:
             __body["version"] = version
         __headers = {"accept": "application/json", "content-type": "application/json"}
@@ -663,7 +662,7 @@ class ClusterClient(NamespacedClient):
         """
         Updates the cluster settings.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/cluster-update-settings.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/cluster-update-settings.html>`_
 
         :param flat_settings: Return settings in flat format (default: false)
         :param master_timeout: Explicit operation timeout for connection to master node
@@ -711,7 +710,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns the information about configured remote clusters.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/cluster-remote-info.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/cluster-remote-info.html>`_
         """
         __path = "/_remote/info"
         __query: t.Dict[str, t.Any] = {}
@@ -757,7 +756,7 @@ class ClusterClient(NamespacedClient):
         """
         Allows to manually change the allocation of individual shards in the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/cluster-reroute.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/cluster-reroute.html>`_
 
         :param commands: Defines the commands to perform.
         :param dry_run: If true, then the request simulates the operation only and returns
@@ -854,7 +853,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns a comprehensive information about the state of the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/cluster-state.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/cluster-state.html>`_
 
         :param metric: Limit the information returned to the specified metrics
         :param index: A comma-separated list of index names; use `_all` or empty string
@@ -932,7 +931,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns high-level overview of cluster statistics.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/cluster-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/cluster-stats.html>`_
 
         :param node_id: Comma-separated list of node filters used to limit returned information.
             Defaults to all nodes in the cluster.
