@@ -41,7 +41,7 @@ class SqlClient(NamespacedClient):
         """
         Clears the SQL cursor
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/clear-sql-cursor-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/clear-sql-cursor-api.html>`_
 
         :param cursor:
         """
@@ -81,7 +81,7 @@ class SqlClient(NamespacedClient):
         Deletes an async SQL search or a stored synchronous SQL search. If the search
         is still running, the API cancels it.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/delete-async-sql-search-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/delete-async-sql-search-api.html>`_
 
         :param id: The async search ID
         """
@@ -124,7 +124,7 @@ class SqlClient(NamespacedClient):
         Returns the current status and available results for an async SQL search or stored
         synchronous SQL search
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/get-async-sql-search-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/get-async-sql-search-api.html>`_
 
         :param id: The async search ID
         :param delimiter: Separator for CSV results. The API only supports this parameter
@@ -178,7 +178,7 @@ class SqlClient(NamespacedClient):
         Returns the current status of an async SQL search or a stored synchronous SQL
         search
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/get-async-sql-search-status-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/get-async-sql-search-status-api.html>`_
 
         :param id: The async search ID
         """
@@ -228,18 +228,7 @@ class SqlClient(NamespacedClient):
         request_timeout: t.Optional[
             t.Union["t.Literal[-1]", "t.Literal[0]", str]
         ] = None,
-        runtime_mappings: t.Optional[
-            t.Mapping[
-                str,
-                t.Union[
-                    t.Mapping[str, t.Any],
-                    t.Union[
-                        t.List[t.Mapping[str, t.Any]],
-                        t.Tuple[t.Mapping[str, t.Any], ...],
-                    ],
-                ],
-            ]
-        ] = None,
+        runtime_mappings: t.Optional[t.Mapping[str, t.Mapping[str, t.Any]]] = None,
         time_zone: t.Optional[str] = None,
         wait_for_completion_timeout: t.Optional[
             t.Union["t.Literal[-1]", "t.Literal[0]", str]
@@ -248,11 +237,12 @@ class SqlClient(NamespacedClient):
         """
         Executes a SQL request
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/sql-search-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/sql-search-api.html>`_
 
         :param catalog: Default catalog (cluster) for queries. If unspecified, the queries
             execute on the data in the local cluster only.
-        :param columnar:
+        :param columnar: If true, the results in a columnar fashion: one row represents
+            all the values of a certain column from the current page of results.
         :param cursor:
         :param fetch_size: The maximum number of rows (or entries) to return in one response
         :param field_multi_value_leniency: Throw an exception when encountering multiple
@@ -349,7 +339,7 @@ class SqlClient(NamespacedClient):
         """
         Translates SQL into Elasticsearch queries
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/sql-translate-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/sql-translate-api.html>`_
 
         :param query:
         :param fetch_size:
